@@ -10,6 +10,7 @@ from sqlglot.dialects.dialect import (
     Dialect,
     datestrtodate_sql,
     inline_array_sql,
+    max_or_greatest,
     min_or_least,
     no_ilike_sql,
     rename_func,
@@ -227,6 +228,7 @@ class BigQuery(Dialect):
             exp.GroupConcat: rename_func("STRING_AGG"),
             exp.ILike: no_ilike_sql,
             exp.IntDiv: rename_func("DIV"),
+            exp.Max: max_or_greatest,
             exp.Min: min_or_least,
             exp.Select: transforms.preprocess(
                 [_unqualify_unnest], transforms.delegate("select_sql")
@@ -253,17 +255,19 @@ class BigQuery(Dialect):
 
         TYPE_MAPPING = {
             **generator.Generator.TYPE_MAPPING,  # type: ignore
-            exp.DataType.Type.TINYINT: "INT64",
-            exp.DataType.Type.SMALLINT: "INT64",
-            exp.DataType.Type.INT: "INT64",
             exp.DataType.Type.BIGINT: "INT64",
-            exp.DataType.Type.DECIMAL: "NUMERIC",
-            exp.DataType.Type.FLOAT: "FLOAT64",
-            exp.DataType.Type.DOUBLE: "FLOAT64",
             exp.DataType.Type.BOOLEAN: "BOOL",
-            exp.DataType.Type.TEXT: "STRING",
-            exp.DataType.Type.VARCHAR: "STRING",
+            exp.DataType.Type.CHAR: "STRING",
+            exp.DataType.Type.DECIMAL: "NUMERIC",
+            exp.DataType.Type.DOUBLE: "FLOAT64",
+            exp.DataType.Type.FLOAT: "FLOAT64",
+            exp.DataType.Type.INT: "INT64",
+            exp.DataType.Type.NCHAR: "STRING",
             exp.DataType.Type.NVARCHAR: "STRING",
+            exp.DataType.Type.SMALLINT: "INT64",
+            exp.DataType.Type.TEXT: "STRING",
+            exp.DataType.Type.TINYINT: "INT64",
+            exp.DataType.Type.VARCHAR: "STRING",
         }
         PROPERTIES_LOCATION = {
             **generator.Generator.PROPERTIES_LOCATION,  # type: ignore
@@ -271,6 +275,7 @@ class BigQuery(Dialect):
         }
 
         EXPLICIT_UNION = True
+        LIMIT_FETCH = "LIMIT"
 
         def array_sql(self, expression: exp.Array) -> str:
             first_arg = seq_get(expression.expressions, 0)
