@@ -3,7 +3,9 @@ from __future__ import annotations
 from sqlglot import exp, generator, parser, tokens
 from sqlglot.dialects.dialect import (
     Dialect,
+    arrow_json_extract_scalar_sql,
     locate_to_strposition,
+    max_or_greatest,
     min_or_least,
     no_ilike_sql,
     no_paren_current_date_sql,
@@ -390,6 +392,8 @@ class MySQL(Dialect):
             exp.CurrentDate: no_paren_current_date_sql,
             exp.CurrentTimestamp: lambda *_: "CURRENT_TIMESTAMP",
             exp.ILike: no_ilike_sql,
+            exp.JSONExtractScalar: arrow_json_extract_scalar_sql,
+            exp.Max: max_or_greatest,
             exp.Min: min_or_least,
             exp.TableSample: no_tablesample_sql,
             exp.TryCast: no_trycast_sql,
@@ -421,6 +425,8 @@ class MySQL(Dialect):
             exp.TransientProperty: exp.Properties.Location.UNSUPPORTED,
         }
 
+        LIMIT_FETCH = "LIMIT"
+
         def show_sql(self, expression):
             this = f" {expression.name}"
             full = " FULL" if expression.args.get("full") else ""
