@@ -6,6 +6,7 @@ import typing as t
 from sqlglot import exp, generator, parser, tokens
 from sqlglot.dialects.dialect import (
     Dialect,
+    max_or_greatest,
     min_or_least,
     parse_date_delta,
     rename_func,
@@ -269,7 +270,6 @@ class TSQL(Dialect):
 
         # TSQL allows @, # to appear as a variable/identifier prefix
         SINGLE_TOKENS = tokens.Tokenizer.SINGLE_TOKENS.copy()
-        SINGLE_TOKENS.pop("@")
         SINGLE_TOKENS.pop("#")
 
     class Parser(parser.Parser):
@@ -435,11 +435,17 @@ class TSQL(Dialect):
             exp.NumberToStr: _format_sql,
             exp.TimeToStr: _format_sql,
             exp.GroupConcat: _string_agg_sql,
+            exp.Max: max_or_greatest,
             exp.Min: min_or_least,
         }
 
         TRANSFORMS.pop(exp.ReturnsProperty)
 
+        LIMIT_FETCH = "FETCH"
+
+        def offset_sql(self, expression: exp.Offset) -> str:
+            return f"{super().offset_sql(expression)} ROWS"
+
         def systemtime_sql(self, expression: exp.SystemTime) -> str:
             kind = expression.args["kind"]
             if kind == "ALL":
