@@ -110,6 +110,10 @@ class Generator:
     # Whether or not MERGE ... WHEN MATCHED BY SOURCE is allowed
     MATCHED_BY_SOURCE = True
 
+    # Whether or not limit and fetch are supported
+    # "ALL", "LIMIT", "FETCH"
+    LIMIT_FETCH = "ALL"
+
     TYPE_MAPPING = {
         exp.DataType.Type.NCHAR: "CHAR",
         exp.DataType.Type.NVARCHAR: "VARCHAR",
@@ -1322,6 +1326,15 @@ class Generator:
         return f"{self.seg('MATCH_RECOGNIZE')} {self.wrap(body)}"
 
     def query_modifiers(self, expression: exp.Expression, *sqls: str) -> str:
+        limit = expression.args.get("limit")
+
+        if self.LIMIT_FETCH == "LIMIT" and isinstance(limit, exp.Fetch):
+            limit = exp.Limit(expression=limit.args.get("count"))
+        elif self.LIMIT_FETCH == "FETCH" and isinstance(limit, exp.Limit):
+            limit = exp.Fetch(direction="FIRST", count=limit.expression)
+
+        fetch = isinstance(limit, exp.Fetch)
+
         return csv(
             *sqls,
             *[self.sql(sql) for sql in expression.args.get("joins") or []],
@@ -1338,8 +1351,8 @@ class Generator:
             self.sql(expression, "sort"),
             self.sql(expression, "cluster"),
             self.sql(expression, "order"),
-            self.sql(expression, "limit"),
-            self.sql(expression, "offset"),
+            self.sql(expression, "offset") if fetch else self.sql(limit),
+            self.sql(limit) if fetch else self.sql(expression, "offset"),
             self.sql(expression, "lock"),
             self.sql(expression, "sample"),
             sep="",
@@ -1577,6 +1590,25 @@ class Generator:
             exp.Case(ifs=[expression.copy()], default=expression.args.get("false"))
         )
 
+    def jsonkeyvalue_sql(self, expression: exp.JSONKeyValue) -> str:
+        return f"{self.sql(expression, 'this')}: {self.sql(expression, 'expression')}"
+
+    def jsonobject_sql(self, expression: exp.JSONObject) -> str:
+        expressions = self.expressions(expression)
+        null_handling = expression.args.get("null_handling")
+        null_handling = f" {null_handling}" if null_handling else ""
+        unique_keys = expression.args.get("unique_keys")
+        if unique_keys is not None:
+            unique_keys = f" {'WITH' if unique_keys else 'WITHOUT'} UNIQUE KEYS"
+        else:
+            unique_keys = ""
+        return_type = self.sql(expression, "return_type")
+        return_type = f" RETURNING {return_type}" if return_type else ""
+        format_json = " FORMAT JSON" if expression.args.get("format_json") else ""
+        encoding = self.sql(expression, "encoding")
+        encoding = f" ENCODING {encoding}" if encoding else ""
+        return f"JSON_OBJECT({expressions}{null_handling}{unique_keys}{return_type}{format_json}{encoding})"
+
     def in_sql(self, expression: exp.In) -> str:
         query = expression.args.get("query")
         unnest = expression.args.get("unnest")
