@@ -11,6 +11,7 @@ from sqlglot.trie import in_trie, new_trie
 
 if t.TYPE_CHECKING:
     from sqlglot.dataframe.sql.types import StructType
+    from sqlglot.dialects.dialect import DialectType
 
     ColumnMapping = t.Union[t.Dict, str, StructType, t.List]
 
@@ -153,7 +154,7 @@ class MappingSchema(AbstractMappingSchema[t.Dict[str, str]], Schema):
         self,
         schema: t.Optional[t.Dict] = None,
         visible: t.Optional[t.Dict] = None,
-        dialect: t.Optional[str] = None,
+        dialect: DialectType = None,
     ) -> None:
         self.dialect = dialect
         self.visible = visible or {}
@@ -305,11 +306,11 @@ class MappingSchema(AbstractMappingSchema[t.Dict[str, str]], Schema):
         return self._type_mapping_cache[schema_type]
 
 
-def ensure_schema(schema: t.Any) -> Schema:
+def ensure_schema(schema: t.Any, dialect: DialectType = None) -> Schema:
     if isinstance(schema, Schema):
         return schema
 
-    return MappingSchema(schema)
+    return MappingSchema(schema, dialect=dialect)
 
 
 def ensure_column_mapping(mapping: t.Optional[ColumnMapping]):
